@@ -28,7 +28,7 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 #include <netinet/in.h>
-
+#include <stdlib.h>
 #include <string.h>
 
 #ifndef SOL_IP
@@ -41,14 +41,20 @@
 
 
 static void
-afinet_set_port(GSockAddr *addr, gint port, gchar *service, gchar *proto)
+afinet_set_port(GSockAddr *addr, gchar *service, gchar *proto)
 {
   if (addr)
     {
-      if (proto)
+      gchar *end;
+      gint port;
+      
+      /* check if service is numeric */
+      port = strtol(service, &end, 10);
+      if ((*end != 0))
         {
           struct servent *se;
           
+          /* service is not numeric, check if it's a service in /etc/services */
           se = getservbyname(service, proto);
           if (se)
             {
@@ -81,7 +87,7 @@ afinet_set_port(GSockAddr *addr, gint port, gchar *service, gchar *proto)
 }
 
 static void
-afinet_resolve_name(GSockAddr *addr, gchar *name)
+afinet_resolve_name(GSockAddr **addr, gchar *name)
 {
   if (addr)
     { 
@@ -90,21 +96,21 @@ afinet_resolve_name(GSockAddr *addr, gchar *name)
       struct addrinfo *res;
 
       memset(&hints, 0, sizeof(hints));
-      hints.ai_family = addr->sa.sa_family;
+      hints.ai_family = (*addr)->sa.sa_family;
       hints.ai_socktype = 0;
       hints.ai_protocol = 0;
       
       if (getaddrinfo(name, NULL, &hints, &res) == 0)
         {
           /* we only use the first entry in the returned list */
-          switch (addr->sa.sa_family)
+          switch ((*addr)->sa.sa_family)
             {
             case AF_INET:
-              g_sockaddr_inet_set_address(addr, ((struct sockaddr_in *) res->ai_addr)->sin_addr);
+              g_sockaddr_inet_set_address((*addr), ((struct sockaddr_in *) res->ai_addr)->sin_addr);
               break;
 #if ENABLE_IPV6
             case AF_INET6:
-              g_sockaddr_inet6_set_address(addr, &((struct sockaddr_in6 *) res->ai_addr)->sin6_addr);
+              *g_sockaddr_inet6_get_sa((*addr)) = *((struct sockaddr_in6 *) res->ai_addr);
               break;
 #endif
             default: 
@@ -115,7 +121,10 @@ afinet_resolve_name(GSockAddr *addr, gchar *name)
         }
       else
         {
-          msg_error("Error resolving hostname, using wildcard address", evt_tag_str("host", name), NULL);
+          msg_error("Error resolving hostname", evt_tag_str("host", name), NULL);
+          g_sockaddr_unref(*addr);
+          *addr = NULL;
+          return;
         }
 #else
       struct hostent *he;
@@ -123,10 +132,10 @@ afinet_resolve_name(GSockAddr *addr, gchar *name)
       he = gethostbyname(name);
       if (he)
         {
-          switch (addr->sa.sa_family)
+          switch ((*addr)->sa.sa_family)
             {
             case AF_INET:
-              g_sockaddr_inet_set_address(addr, *(struct in_addr *) he->h_addr);
+              g_sockaddr_inet_set_address((*addr), *(struct in_addr *) he->h_addr);
               break;
             default: 
               g_assert_not_reached();
@@ -136,7 +145,9 @@ afinet_resolve_name(GSockAddr *addr, gchar *name)
         }
       else
         {
-          msg_error("Error resolving hostname, using wildcard address", evt_tag_str("host", name), NULL);
+          msg_error("Error resolving hostname", evt_tag_str("host", name), NULL);
+          g_sockaddr_unref(*addr);
+          *addr = NULL;
         }
 #endif
     }
@@ -218,11 +229,11 @@ afinet_setup_socket(gint fd, GSockAddr *addr, InetSocketOptions *sock_options, A
 }
 
 void 
-afinet_sd_set_localport(LogDriver *s, gint port, gchar *service, gchar *proto)
+afinet_sd_set_localport(LogDriver *s, gchar *service, gchar *proto)
 {
   AFSocketSourceDriver *self = (AFSocketSourceDriver *) s;
   
-  afinet_set_port(self->bind_addr, port, service, proto);
+  afinet_set_port(self->bind_addr, service, proto);
 }
 
 void 
@@ -230,7 +241,7 @@ afinet_sd_set_localip(LogDriver *s, gchar *ip)
 {
   AFSocketSourceDriver *self = (AFSocketSourceDriver *) s;
   
-  afinet_resolve_name(self->bind_addr, ip);
+  afinet_resolve_name(&self->bind_addr, ip);
 }
 
 static gboolean
@@ -262,7 +273,7 @@ afinet_sd_new(gint af, gchar *host, gint port, guint flags)
       g_assert_not_reached();
 #endif
     }
-  afinet_resolve_name(self->super.bind_addr, host);
+  afinet_resolve_name(&self->super.bind_addr, host);
   self->super.setup_socket = afinet_sd_setup_socket;
     
   return &self->super.super;
@@ -271,19 +282,19 @@ afinet_sd_new(gint af, gchar *host, gint port, guint flags)
 /* afinet destination */
 
 void 
-afinet_dd_set_localport(LogDriver *s, gint port, gchar *service, gchar *proto)
+afinet_dd_set_localport(LogDriver *s, gchar *service, gchar *proto)
 {
   AFInetDestDriver *self = (AFInetDestDriver *) s;
   
-  afinet_set_port(self->super.bind_addr, port, service, proto);
+  afinet_set_port(self->super.bind_addr, service, proto);
 }
 
 void 
-afinet_dd_set_destport(LogDriver *s, gint port, gchar *service, gchar *proto)
+afinet_dd_set_destport(LogDriver *s, gchar *service, gchar *proto)
 {
   AFInetDestDriver *self = (AFInetDestDriver *) s;
   
-  afinet_set_port(self->super.dest_addr, port, service, proto);
+  afinet_set_port(self->super.dest_addr, service, proto);
 }
 
 void 
@@ -291,7 +302,7 @@ afinet_dd_set_localip(LogDriver *s, gchar *ip)
 {
   AFInetDestDriver *self = (AFInetDestDriver *) s;
   
-  afinet_resolve_name(self->super.bind_addr, ip);
+  afinet_resolve_name(&self->super.bind_addr, ip);
 }
 
 void 
@@ -339,6 +350,7 @@ afinet_dd_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
         }
     }
 #endif
+  
   return success;
 }
 
@@ -529,7 +541,7 @@ afinet_dd_new(gint af, gchar *host, gint port, guint flags)
       g_assert_not_reached();
 #endif
     }
-  afinet_resolve_name(self->super.dest_addr, host);
+  afinet_resolve_name(&self->super.dest_addr, host);
   self->super.setup_socket = afinet_dd_setup_socket;
   return &self->super.super;
 }
