@@ -236,6 +236,10 @@ static gboolean
 afsocket_sc_deinit(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
 {
   AFSocketSourceConnection *self = (AFSocketSourceConnection *) s;
+
+  self->owner->connections = g_list_remove(self->owner->connections, self);
+  log_pipe_unref(&self->owner->super.super);
+  self->owner = NULL;
   
   log_pipe_deinit(self->reader, NULL, NULL);
   log_pipe_unref(self->reader);
@@ -292,8 +296,6 @@ afsocket_sc_free(LogPipe *s)
 {
   AFSocketSourceConnection *self = (AFSocketSourceConnection *) s;
 
-  self->owner->connections = g_list_remove(self->owner->connections, self);
-  log_pipe_unref(&self->owner->super.super);
   
   g_assert(!self->reader);
   g_sockaddr_unref(self->peer_addr);
@@ -367,9 +369,9 @@ afsocket_sd_process_connection(AFSocketSourceDriver *self, GSockAddr *peer_addr,
         {
           gchar buf[256];
           
-          msg_verbose("Syslog connection rejected by tcpd",
-                      evt_tag_str("from", g_sockaddr_format(peer_addr, buf, sizeof(buf))),
-                      NULL);
+          msg_error("Syslog connection rejected by tcpd",
+                    evt_tag_str("from", g_sockaddr_format(peer_addr, buf, sizeof(buf))),
+                    NULL);
           close(fd);
           return TRUE;
         }
@@ -389,6 +391,7 @@ afsocket_sd_process_connection(AFSocketSourceDriver *self, GSockAddr *peer_addr,
     {
       AFSocketSourceConnection *conn;
       
+      self->num_connections++;
       conn = afsocket_sc_new(self, peer_addr, fd);
       log_pipe_init(&conn->super, NULL, NULL);
       log_pipe_append(&conn->super, &self->super.super);
@@ -437,6 +440,7 @@ afsocket_sd_close_connection(AFSocketSourceDriver *self, AFSocketSourceConnectio
 {
   log_pipe_deinit(&sc->super, NULL, NULL);
   log_pipe_unref(&sc->super);
+  self->num_connections--;
 }
 
 static void
@@ -689,6 +693,9 @@ afsocket_dd_format_stats_name(AFSocketDestDriver *self)
     case AF_INET:
       driver_name = !!(self->flags & AFSOCKET_STREAM) ? "tcp" : "udp";
       break;
+    case AF_INET6:
+      driver_name = !!(self->flags & AFSOCKET_STREAM) ? "tcp6" : "udp6";
+      break;    
     }
   
   g_snprintf(stats_name, sizeof(stats_name), "%s(%s)", 
