@@ -68,9 +68,9 @@ afunix_sd_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
   
   if (afsocket_sd_init(s, cfg, persist))
     {
-      if (self->owner != -1 || self->group != -1)
+      if (self->owner != (uid_t) -1 || self->group != (gid_t) -1)
         chown(self->filename, self->owner, self->group);
-      if (self->perm != -1)
+      if (self->perm != (mode_t) -1)
         chmod(self->filename, self->perm);
       return TRUE;
     }
@@ -93,6 +93,7 @@ afunix_sd_new(gchar *filename, guint32 flags)
   AFUnixSourceDriver *self = g_new0(AFUnixSourceDriver, 1);
 
   afsocket_sd_init_instance(&self->super, &self->sock_options, flags);
+  self->super.max_connections = 256;
   self->super.flags |= AFSOCKET_KEEP_ALIVE;
   self->super.bind_addr = g_sockaddr_unix_new(filename);
   self->super.super.super.init = afunix_sd_init;
