@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2007 BalaBit IT Ltd, Budapest, Hungary                    
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -53,7 +53,9 @@ afuser_dd_queue(LogPipe *s, LogMessage *msg, gint path_flags)
   gchar buf[8192];
   struct utmp *ut;
   
-  g_snprintf(buf, sizeof(buf), "%s %s %s\n", msg->date->str, msg->host->str, msg->msg->str);
+  g_snprintf(buf, sizeof(buf), "%s %s %s\n", msg->date.str, msg->host.str, msg->msg.str);
+  
+  /* NOTE: there's a private implementations of getutent in utils.c on Systems which do not provide one. */
   while ((ut = getutent())) 
     {
 #if HAVE_MODERN_UTMP
@@ -85,6 +87,7 @@ afuser_dd_queue(LogPipe *s, LogMessage *msg, gint path_flags)
             }
         }
     }
+  endutent();
   if ((path_flags & PF_FLOW_CTL_OFF) == 0)
     log_msg_ack(msg);
   log_msg_unref(msg);
