@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2007 BalaBit IT Ltd, Budapest, Hungary                    
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -37,8 +37,17 @@ typedef struct _LogDestGroup
   guint32 *processed_messages;
 } LogDestGroup;
 
-#define log_dgrp_ref(s)     ((LogDestGroup *) log_pipe_ref((LogPipe *) s))
-#define log_dgrp_unref(s)   log_pipe_unref((LogPipe *) s)
+static inline LogDestGroup *
+log_dest_group_ref(LogDestGroup *self)
+{
+  return (LogDestGroup *) log_pipe_ref(&self->super);
+}
+
+static inline void
+log_dest_group_unref(LogDestGroup *self)
+{
+  log_pipe_unref(&self->super);
+}
 
 LogDestGroup *log_dest_group_new(gchar *name, LogDriver *drivers);
 
