@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2007 BalaBit IT Ltd, Budapest, Hungary                    
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -31,11 +31,6 @@ log_drv_append(LogDriver *self, LogDriver *next)
   self->drv_next = log_drv_ref(next);
 }
 
-void 
-log_drv_set_fifo_size(LogDriver *self, gint fifo_size)
-{
-}
-
 void
 log_drv_init_instance(LogDriver *s)
 {
