@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2007 BalaBit IT Ltd, Budapest, Hungary                    
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -29,16 +29,28 @@
 static size_t
 fd_do_read(FDRead *self, void *buf, size_t buflen, GSockAddr **sa)
 {
+  gint rc;
+  
   if ((self->flags & FR_RECV) == 0)
     {
       *sa = NULL;
-      return read(self->fd, buf, buflen);
+      do
+        {
+          rc = read(self->fd, buf, buflen);
+        }
+      while (rc == -1 && errno == EINTR);
     }
   else 
     {
-      struct sockaddr_storage sas;
+      union
+      {
+#if HAVE_STRUCT_SOCKADDR_STORAGE
+        struct sockaddr_storage __sas;
+#endif
+        struct sockaddr __sa;
+      } sas;
+      
       socklen_t salen = sizeof(sas);
-      gint rc;
 
       do
         {
@@ -48,8 +60,8 @@ fd_do_read(FDRead *self, void *buf, size_t buflen, GSockAddr **sa)
       while (rc == -1 && errno == EINTR);
       if (rc != -1 && salen)
         (*sa) = g_sockaddr_new((struct sockaddr *) &sas, salen);
-      return rc;
     }
+  return rc;
 }
 
 FDRead *
