@@ -208,8 +208,10 @@ log_msg_parse(LogMessage *self, gchar *data, gint length, guint flags, regex_t *
       self->stamp.time.tv_usec = 0;
       
       p = memchr(src, ' ', left);
-      
-      stamp_length = (p - src);
+      if (p)
+        stamp_length = (p - src);
+      else
+        stamp_length = left;
       
       g_string_assign_len(&self->date, src, stamp_length);
       
@@ -229,13 +231,13 @@ log_msg_parse(LogMessage *self, gchar *data, gint length, guint flags, regex_t *
           /* process second fractions */
           
           p++;
-          while (isdigit(*p))
+          while (div < 10e6 && isdigit(*p))
             {
               frac = 10 * frac + (*p) - '0';
               div = div * 10;
               p++;
             }
-          self->stamp.time.tv_usec = frac * 1000000 / div;
+          self->stamp.time.tv_usec = frac * (1000000 / div);
         }
       if (p && (*p == '+' || *p == '-') && strlen(p) == 6 && 
           isdigit(*(p+1)) && isdigit(*(p+2)) && *(p+3) == ':' && isdigit(*(p+4)) && isdigit(*(p+5)))
@@ -268,18 +270,64 @@ log_msg_parse(LogMessage *self, gchar *data, gint length, guint flags, regex_t *
       src += stamp_length;
       left -= stamp_length;
     }
-  else if (left >= 15 && src[3] == ' ' && src[6] == ' ' && src[9] == ':' && src[12] == ':')
+  else if (left >= 21 && src[3] == ' ' && src[6] == ' ' && src[11] == ' ' && src[14] == ':' && src[17] == ':' && src[20] == ':')
     {
-      /* RFC 3164 timestamp, expected format: MMM DD HH:MM:SS ... */
+      /* PIX timestamp, expected format: MMM DD YYYY HH:MM:SS: */
+
       struct tm tm, *nowtm;
 
       /* Just read the buffer data into a textual
          datestamp. */
 
+      g_string_assign_len(&self->date, src, 21);
+      src += 21;
+      left -= 21;
+
+      /* And also make struct time timestamp for the msg */
+
+      nowtm = localtime(&now);
+      tm = *nowtm;
+      strptime(self->date.str, "%b %e %Y %H:%M:%S:", &tm);
+      tm.tm_isdst = -1;
+        
+      /* NOTE: no timezone information in the message, assume it is local time */
+      self->stamp.time.tv_sec = mktime(&tm);
+      self->stamp.time.tv_usec = 0;
+      
+    }
+  else if (left >= 15 && src[3] == ' ' && src[6] == ' ' && src[9] == ':' && src[12] == ':')
+    {
+      /* RFC 3164 timestamp, expected format: MMM DD HH:MM:SS ... */
+      struct tm tm, *nowtm;
+      glong usec = 0;
+
+      /* Just read the buffer data into a textual
+         datestamp. */
+         
+
       g_string_assign_len(&self->date, src, 15);
       src += 15;
       left -= 15;
 
+      if (left > 0 && src[0] == '.')
+        {
+          gulong frac = 0;
+          gint div = 1;
+          gint i = 1;
+          
+          /* gee, funny Cisco extension, BSD timestamp with fraction of second support */
+
+          while (i < left && div < 10e6 && isdigit(src[i]))
+            {
+              frac = 10 * frac + (src[i]) - '0';
+              div = div * 10;
+              i++;
+            }
+          usec = frac * (1000000 / div);
+          left -= i;
+          src += i;
+        }
+
       /* And also make struct time timestamp for the msg */
 
       nowtm = localtime(&now);
@@ -292,10 +340,12 @@ log_msg_parse(LogMessage *self, gchar *data, gint length, guint flags, regex_t *
         
       /* NOTE: no timezone information in the message, assume it is local time */
       self->stamp.time.tv_sec = mktime(&tm);
-      self->stamp.time.tv_usec = 0;
-      self->stamp.zone_offset = get_local_timezone_ofs(self->stamp.time.tv_sec); /* assume local timezone */
+      self->stamp.time.tv_usec = usec;
     }
     
+  if (self->stamp.zone_offset == -1)
+    self->stamp.zone_offset = get_local_timezone_ofs(self->stamp.time.tv_sec); /* assume local timezone */
+    
   if (self->date.len)
     {
       /* Expected format: hostname program[pid]: */
@@ -396,7 +446,8 @@ log_msg_parse(LogMessage *self, gchar *data, gint length, guint flags, regex_t *
 	  /* Try to extract a program name */
 	  oldsrc = src;
 	  oldleft = left;
-	  while (left && *src != ':' && *src != '[')
+	  while (left && *src != ' ' && *src != '['
+		 && *src != ':' && *src != '/' && *src != ',' && *src != '<')
 	    {
 	      src++;
 	      left--;
@@ -416,6 +467,7 @@ log_msg_parse(LogMessage *self, gchar *data, gint length, guint flags, regex_t *
     }
   else
     {
+      /* no timestamp, format is expected to be "program[pid] message" */
       /* Different format */
 
       oldsrc = src;
@@ -546,7 +598,8 @@ log_msg_init(LogMessage *self, GSockAddr *saddr)
   self->ref_cnt = 1;
   gettimeofday(&self->recvd.time, NULL);
   self->recvd.zone_offset = get_local_timezone_ofs(self->recvd.time.tv_sec);
-  self->stamp = self->recvd;
+  self->stamp.time = self->recvd.time;
+  self->stamp.zone_offset = -1;
   log_msg_init_string(&self->date, 16);
   log_msg_init_string(&self->host, 32);
   log_msg_init_string(&self->host_from, 32);
