@@ -34,6 +34,8 @@
 #include <time.h>
 #include <errno.h>
 
+#include <stdio.h>
+
 static gboolean log_reader_fetch_log(LogReader *self, FDRead *fd);
 
 typedef struct _LogReaderWatch
@@ -50,12 +52,14 @@ log_reader_fd_prepare(GSource *source,
 {
   LogReaderWatch *self = (LogReaderWatch *) source;
 
+  
+#if 0
   /* FIXME: this debug message references a variable outside of its scope, 
    * but it is a debug message only */
-  
   msg_debug("log_reader_fd_prepare()", 
             evt_tag_int("window_size", self->reader->options->source_opts.window_size), 
             NULL);
+#endif
 
   self->pollfd.revents = 0;
   self->pollfd.events = 0;
@@ -93,18 +97,40 @@ log_reader_fd_check(GSource *source)
   
   if (self->reader->flags & LR_FOLLOW)
     {
-      struct stat st;
+      struct stat st, followed_st;
       off_t pos;
       
-      pos = lseek(self->fd->fd, 0, SEEK_CUR);
-      if (pos == -1)
-        return FALSE;
-      
-      if (fstat(self->fd->fd, &st) == -1)
-	return FALSE;
+      pos = lseek(self->fd->fd, 0, SEEK_CUR);      
+      if (pos == (off_t) -1)
+        {
+          msg_error("Error invoking seek on followed file",
+                    evt_tag_errno("error", errno),
+                    NULL);
+          return FALSE;
+        }
 
-      if (pos != st.st_size)
+      if (fstat(self->fd->fd, &st) < 0)
+        {
+          msg_error("Error invoking fstat() on followed file",
+                    evt_tag_errno("error", errno),
+                    NULL);
+          return FALSE;
+        }
+      
+      if (pos < st.st_size)
 	return TRUE;
+
+      if (self->reader->options->follow_filename && stat(self->reader->options->follow_filename, &followed_st) != -1)
+        {
+          if (st.st_ino != followed_st.st_ino)
+            {
+              /* file was moved and we are at EOF, follow the new file */
+              log_pipe_notify(self->reader->control, &self->reader->super.super, NC_FILE_MOVED, self);
+              return TRUE;
+            }
+          return FALSE;
+        }
+      
       return FALSE;
     }
     
@@ -287,7 +313,6 @@ log_reader_iterate_buf(LogReader *self, GSockAddr *saddr, gboolean flush, gint *
 static gboolean
 log_reader_fetch_log(LogReader *self, FDRead *fd)
 {
-  guint avail = self->options->msg_size - self->ofs;
   gint rc;
   GSockAddr *sa = NULL;
   gint msg_count = 0;
@@ -297,26 +322,13 @@ log_reader_fetch_log(LogReader *self, FDRead *fd)
     {
       log_reader_iterate_buf(self, NULL, FALSE, &msg_count);
       
-      /* we still have something */
-      if (self->ofs != 0)
+      /* we still have something that could not be emptied, or multiread is
+       * disabled and we did not check readability when we came here.
+       */
+      if (self->ofs != 0 || (self->flags & LR_NOMREAD))
         return TRUE;
     }
   
-  /* check for new data */
-  if (self->options->padding)
-    {
-      if (avail < self->options->padding)
-	{
-	  msg_error("Buffer is too small to hold padding number of bytes",
-	            evt_tag_int(EVT_TAG_FD, fd->fd),
-	            evt_tag_int("padding", self->options->padding),
-                    evt_tag_int("avail", avail),
-                    NULL);
-          log_pipe_notify(self->control, &self->super.super, NC_CLOSE, self);
-	  return FALSE;
-	}
-      avail = self->options->padding;
-    }
   
   /* NOTE: this loop is here to decrease the load on the main loop, we try
    * to fetch a couple of messages in a single run (but only up to
@@ -324,7 +336,13 @@ log_reader_fetch_log(LogReader *self, FDRead *fd)
    */
   while (msg_count < self->options->fetch_limit)
     {
-      avail = self->options->msg_size - self->ofs;
+      gint avail;
+      
+      if (!self->options->padding)
+        avail = self->options->msg_size - self->ofs;
+      else
+        avail = self->options->padding;
+        
       sa = NULL;
       rc = fd_read(fd, self->buffer + self->ofs, avail, &sa);
 
@@ -388,6 +406,19 @@ log_reader_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
 {
   LogReader *self = (LogReader *) s;
   
+  /* check for new data */
+  if (self->options->padding)
+    {
+      if (self->options->msg_size < self->options->padding)
+	{
+	  msg_error("Buffer is too small to hold padding number of bytes",
+	            evt_tag_int("padding", self->options->padding),
+                    evt_tag_int("msg_size", self->options->msg_size),
+                    NULL);
+	  return FALSE;
+	}
+    }
+
   /* the source added below references this logreader, it will be unref'd
      when the source is destroyed */ 
   self->source = log_reader_watch_new(self, self->fd);
@@ -443,6 +474,11 @@ log_reader_set_options(LogPipe *s, LogReaderOptions *options)
 void
 log_reader_set_pos(LogReader *self, off_t ofs)
 {
+  off_t size;
+  
+  size = lseek(self->fd->fd, 0, SEEK_END);
+  if (ofs > size)
+    ofs = size;
   if (lseek(self->fd->fd, ofs, SEEK_SET) >= 0)
     self->ofs = 0;
 }
