@@ -251,13 +251,13 @@ log_writer_format_log(LogWriter *self, LogMessage *lm, GString *result)
       if (self->flags & LW_FORMAT_FILE)
         {
           log_stamp_format(stamp, ts, self->options->ts_format, self->options->zone_offset, self->options->frac_digits);
-          g_string_sprintf(result, "%s %s %s\n", ts->str, lm->host->str, lm->msg->str);
+          g_string_sprintf(result, "%s %s %s\n", ts->str, lm->host.str, lm->msg.str);
         }
       else if (self->flags & LW_FORMAT_PROTO)
         {
           /* always use BSD timestamp by default, the use can override this using a custom template */
           log_stamp_format(stamp, ts, TS_FMT_BSD, self->options->zone_offset, self->options->frac_digits);
-          g_string_sprintf(result, "<%d>%s %s %s\n", lm->pri, ts->str, lm->host->str, lm->msg->str);
+          g_string_sprintf(result, "<%d>%s %s %s\n", lm->pri, ts->str, lm->host.str, lm->msg.str);
         }
       g_string_free(ts, TRUE);
     }
@@ -479,7 +479,7 @@ log_writer_options_set_template_escape(LogWriterOptions *options, gboolean enabl
     }
   else
     {
-      msg_notice("Macro escaping can only be specified for inline templates", NULL);
+      msg_error("Macro escaping can only be specified for inline templates", NULL);
     }
 }
 
@@ -499,7 +499,7 @@ log_writer_options_init(LogWriterOptions *options, GlobalConfig *cfg, guint32 fl
   options->template = template;
   options->flags = flags;
   if (options->fifo_size == -1)
-    options->fifo_size = cfg->log_fifo_size;
+    options->fifo_size = MAX(1000, cfg->log_fifo_size);
   if (options->use_time_recvd == -1)
     options->use_time_recvd = cfg->use_time_recvd;
     
