@@ -50,7 +50,7 @@
 static char cfgfilename[128] = PATH_SYSLOG_NG_CONF;
 static char pidfilename[128] = PATH_PIDFILE;
 
-static gboolean do_fork = 1;
+static gboolean do_fork = TRUE;
 static gboolean sig_hup_received = FALSE;
 static gboolean sig_term_received = FALSE;
 static gboolean sig_child_received = FALSE;
@@ -76,6 +76,7 @@ void usage(void)
 	 "  -C <dir>, --chroot=<dir>         Chroot to directory\n"
 	 "  -u <user>, --user=<user>         Switch to user\n"
 	 "  -g <group>, --group=<group>      Switch to group\n"
+	 "  --ignore-persistent              Ignore persistent configuration file\n"
 #ifdef YYDEBUG
 	 "  -y, --yydebug                    Turn on yacc debug messages\n"
 #endif
@@ -137,7 +138,7 @@ stats_timer(gpointer st)
 }
 
 int 
-main_loop_run(GlobalConfig *cfg)
+main_loop_run(GlobalConfig **cfg)
 {
   GMainLoop *main_loop;
   gint iters;
@@ -147,36 +148,36 @@ main_loop_run(GlobalConfig *cfg)
              evt_tag_str("version", VERSION),
              NULL);
   main_loop = g_main_loop_new(NULL, TRUE);
-  if (cfg->stats_freq > 0)
-    stats_timer_id = g_timeout_add(cfg->stats_freq * 1000, stats_timer, NULL);
+  if ((*cfg)->stats_freq > 0)
+    stats_timer_id = g_timeout_add((*cfg)->stats_freq * 1000, stats_timer, NULL);
   while (g_main_loop_is_running(main_loop))
     {
-      if (cfg->time_sleep > 0)
+      if ((*cfg)->time_sleep > 0)
         {
           struct timespec ts;
           
-          ts.tv_sec = cfg->time_sleep / 1000;
-          ts.tv_nsec = (cfg->time_sleep % 1000) * 1E6;
+          ts.tv_sec = (*cfg)->time_sleep / 1000;
+          ts.tv_nsec = ((*cfg)->time_sleep % 1000) * 1E6;
           
           nanosleep(&ts, NULL);
         }
       g_main_context_iteration(g_main_loop_get_context(main_loop), TRUE);
       if (sig_hup_received)
         {
-          msg_notice("SIGHUP received, reloading configuration", NULL);
-          cfg = cfg_reload_config(cfgfilename, cfg);
+          msg_notice("Configuration reload request received, reloading configuration", NULL);
+          (*cfg) = cfg_reload_config(cfgfilename, (*cfg));
           sig_hup_received = FALSE;
-          if (cfg->stats_freq > 0)
+          if ((*cfg)->stats_freq > 0)
             {
               if (stats_timer_id != 0)
                 g_source_remove(stats_timer_id);
-              stats_timer_id = g_timeout_add(cfg->stats_freq * 1000, stats_timer, NULL);
+              stats_timer_id = g_timeout_add((*cfg)->stats_freq * 1000, stats_timer, NULL);
             }
           stats_cleanup_orphans();
         }
       if (sig_term_received)
         {
-          msg_notice("Termination requested via signal, terminating", NULL);
+          msg_info("Termination requested via signal, terminating", NULL);
           sig_term_received = FALSE;
           break;
         }
@@ -203,8 +204,6 @@ main_loop_run(GlobalConfig *cfg)
     {
       iters++;
     }
-  cfg_deinit(cfg, NULL);
-  cfg_free(cfg);
   g_main_loop_unref(main_loop);
   return 0;
 }
@@ -302,6 +301,7 @@ main(int argc, char *argv[])
 {
   GlobalConfig *cfg;
 
+  /* FIXME: use Glib's option parser to avoid having to rely on getopt_long */
 #if HAVE_GETOPT_LONG
   struct option syslog_ng_options[] = 
     {
@@ -323,9 +323,11 @@ main(int argc, char *argv[])
       { NULL, 0, NULL, 0 }
     };
 #endif
-  int syntax_only = 0;
-  int log_to_stderr = 0;
+  gboolean syntax_only = FALSE;
+  gboolean log_to_stderr = FALSE;
+  PersistentConfig *persist = NULL;
   int opt, rc;
+  
 
 #if HAVE_GETOPT_LONG
   while ((opt = getopt_long(argc, argv, "sFf:p:dvhyVC:u:g:e", syslog_ng_options, NULL)) != -1)
@@ -342,7 +344,7 @@ main(int argc, char *argv[])
 	  strncpy(pidfilename, optarg, sizeof(pidfilename));
 	  break;
 	case 's':
-	  syntax_only = 1;
+	  syntax_only = TRUE;
 	  break;
 	case 'd':
 	  debug_flag++;
@@ -351,10 +353,10 @@ main(int argc, char *argv[])
 	  verbose_flag++;
 	  break;
 	case 'e':
-	  log_to_stderr = 1;
+	  log_to_stderr = TRUE;
 	  break;
 	case 'F':
-	  do_fork = 0;
+	  do_fork = FALSE;
 	  break;
 	case 'V':
 	  printf(PACKAGE " " VERSION "\n");
@@ -373,7 +375,7 @@ main(int argc, char *argv[])
 	  break;
 #ifdef YYDEBUG
 	case 'y':
-	  yydebug = 1;
+	  yydebug = TRUE;
 	  break;
 #endif
 	case 'h':
@@ -403,8 +405,10 @@ main(int argc, char *argv[])
       return 0;
     }
 
+  persist = persist_config_new();
+  persist_config_load(persist);
 
-  if (!cfg_init(cfg, NULL))
+  if (!cfg_init(cfg, persist))
     {
       return 2;
     }
@@ -418,9 +422,21 @@ main(int argc, char *argv[])
   
   setup_creds();
   setup_std_fds(log_to_stderr);
+  
+  rc = main_loop_run(&cfg);
 
-  rc = main_loop_run(cfg);
+  cfg_deinit(cfg, persist);
+  
+  if (persist)
+    {
+      persist_config_save(persist);
+      persist_config_free(persist);
+    }
+
+  cfg_free(cfg);
+  
   child_manager_deinit();
+
   msg_deinit();
   dns_cache_destroy();
   z_mem_trace_dump();
