@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2007 BalaBit IT Ltd, Budapest, Hungary                    
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -26,7 +26,7 @@
 
 void z_mem_trace_init(gchar *memtrace_file);
 void z_mem_trace_stats(void);
-void z_mem_trace_dump();
+void z_mem_trace_dump(void);
 
 #if ENABLE_MEM_TRACE
 
