@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2007 BalaBit IT Ltd, Budapest, Hungary                    
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -36,17 +36,23 @@
 
 #include <glib.h>
 
-#if ENABLE_DEBUG
-#define PATH_SYSLOG_NG_CONF     "syslog-ng.conf"
-#define PATH_PIDFILE            "syslog-ng.pid"
-#else
 #define PATH_SYSLOG_NG_CONF     PATH_SYSCONFDIR "/syslog-ng.conf"
 #define PATH_PIDFILE            "/var/run/syslog-ng.pid"
-#endif
+#define PATH_PERSIST_CONFIG     PATH_LOCALSTATEDIR "/syslog-ng.persist"
 
 #define LOG_PRIORITY_LISTEN 0
 #define LOG_PRIORITY_READER 0
 #define LOG_PRIORITY_WRITER -100
 #define LOG_PRIORITY_CONNECT -150
 
+#if !HAVE_STRTOLL
+# if HAVE_STRTOIMAX || defined(strtoimax)
+   /* HP-UX has an strtoimax macro, not a function */
+   #define strtoll(nptr, endptr, base) strtoimax(nptr, endptr, base)
+# else
+   /* this requires Glib 2.12 */
+   #define strtoll(nptr, endptr, base) g_ascii_strtoll(nptr, endptr, base)
+# endif
+#endif
+
 #endif
